@@ -1,24 +1,26 @@
-# 
+#
 # This file is part of Games-Pandemic
-# 
+#
 # This software is Copyright (c) 2009 by Jerome Quelin.
-# 
+#
 # This is free software, licensed under:
-# 
+#
 #   The GNU General Public License, Version 2, June 1991
-# 
+#
 use 5.010;
 use strict;
 use warnings;
 
 package Games::Pandemic::Config;
-our $VERSION = '1.092660';
-
+BEGIN {
+  $Games::Pandemic::Config::VERSION = '1.111010';
+}
 # ABSTRACT: pandemic local configuration
 
 use Games::Pandemic::Utils;
 use MooseX::Singleton;          # should come before any other moose
-use MooseX::AttributeHelpers;
+use Moose      0.92;
+use MooseX::Has::Sugar;
 use MooseX::SemiAffordanceAccessor;
 use YAML::Tiny qw{ LoadFile };
 
@@ -31,18 +33,26 @@ my $default = {
 
 # -- accessors
 
-has '_options' => (
-    metaclass => 'Collection::Hash',
-    is        => 'ro',
-    isa       => 'HashRef[Str]',
-    builder   => '_build_options',
-    provides  => {
-        'set'    => 'set',
-        'get'    => '_get',
-        'exists' => '_exists',
+has _options => (
+    ro,
+    traits  => ['Hash'],
+    isa     => 'HashRef[Str]',
+    builder => '_build_options',
+    handles => {
+        set     => 'set',
+        _get    => 'get',
+        _exists => 'exists',
     }
 );
 
+# -- initializer
+
+sub _build_options {
+    my $yaml = eval { LoadFile( "$CONFIGDIR/config.yaml" ) };
+    return $@ ? {} : $yaml;
+}
+
+
 # -- public methods
 
 
@@ -51,13 +61,6 @@ sub get {
     my $val = $self->_get($key) // $default->{$key};
 }
 
-# -- private subs
-
-sub _build_options {
-    my $yaml = eval { LoadFile( "$CONFIGDIR/config.yaml" ) };
-    return $@ ? {} : $yaml;
-}
-
 
 no Moose;
 __PACKAGE__->meta->make_immutable;
@@ -65,7 +68,6 @@ __PACKAGE__->meta->make_immutable;
 1;
 
 
-
 =pod
 
 =head1 NAME
@@ -74,7 +76,7 @@ Games::Pandemic::Config - pandemic local configuration
 
 =head1 VERSION
 
-version 1.092660
+version 1.111010
 
 =head1 SYNOPSIS
 
@@ -98,11 +100,9 @@ Return the C<$value> associated to C<$key> in the configuration.
 Note that if there's no local configuration defined, a default will
 be provided.
 
-
-
 =head1 AUTHOR
 
-  Jerome Quelin
+Jerome Quelin
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -112,8 +112,8 @@ This is free software, licensed under:
 
   The GNU General Public License, Version 2, June 1991
 
-=cut 
+=cut
 
 
+__END__
 
-__END__
\ No newline at end of file
