@@ -1,24 +1,25 @@
-# 
+#
 # This file is part of Games-Pandemic
-# 
+#
 # This software is Copyright (c) 2009 by Jerome Quelin.
-# 
+#
 # This is free software, licensed under:
-# 
+#
 #   The GNU General Public License, Version 2, June 1991
-# 
+#
 use 5.010;
 use strict;
 use warnings;
 
 package Games::Pandemic::Disease;
-our $VERSION = '1.092660';
-
+BEGIN {
+  $Games::Pandemic::Disease::VERSION = '1.111010';
+}
 # ABSTRACT: pandemic disease object
 
 use File::Spec::Functions qw{ catfile };
-use Moose;
-use MooseX::AttributeHelpers;
+use Moose                 0.92;
+use MooseX::Has::Sugar;
 use MooseX::SemiAffordanceAccessor;
 
 use Games::Pandemic::Utils;
@@ -26,47 +27,41 @@ use Games::Pandemic::Utils;
 
 # -- attributes
 
-has 'colors' => (
-    metaclass  => 'Collection::List',
-    is         => 'ro',
-    isa        => 'ArrayRef[Str]',
-    required   => 1,
-    provides   => { get => 'color' },
+has colors => (
+    ro, required,
+    traits   => ['Array'],
+    isa      => 'ArrayRef[Str]',
+    handles  => { color => 'get' },
 );
-has id    => ( is => 'ro', isa => 'Int', required   => 1 );
-has name  => ( is => 'ro', isa => 'Str', required   => 1 );
+has id    => ( ro, required, isa => 'Int' );
+has name  => ( ro, required, isa => 'Str' );
 has nbleft => (
-    metaclass  => 'Number',
-    is         => 'ro',
-    isa        => 'Int',
-    lazy       => 1,
-    builder    => '_build_nb',
-    provides   => {
-        add => 'return',
-        sub => 'take',
+    ro, lazy,
+    traits  => ['Number'],
+    isa     => 'Int',
+    builder => '_build_nb',
+    handles => {
+        return => 'add',
+        take   => 'sub',
     },
 );
-has nbmax => ( is => 'ro', isa => 'Int', required   => 1 );
-has _map  => ( is => 'ro', isa => 'Games::Pandemic::Map',required => 1, weak_ref => 1 );
+has nbmax => ( ro, required, isa => 'Int' );
+has _map  => ( ro, required, weak_ref, isa => 'Games::Pandemic::Map' );
 
 has has_cure => (
-    metaclass => 'Bool',
-    is        => 'ro',
-    isa       => 'Bool',
-    default   => 0,
-    provides  => {
-        set     => 'find_cure',
-    }
+    ro,
+    traits  => ['Bool'],
+    isa     => 'Bool',
+    default => 0,
+    handles => { find_cure => 'set' },
 );
 
 has is_eradicated => (
-    metaclass => 'Bool',
-    is        => 'ro',
-    isa       => 'Bool',
-    default   => 0,
-    provides  => {
-        set     => 'eradicate',
-    }
+    ro,
+    traits  => ['Bool'],
+    isa     => 'Bool',
+    default => 0,
+    handles => { eradicate => 'set' },
 );
 
 # -- default builders / finishers
@@ -94,7 +89,6 @@ __PACKAGE__->meta->make_immutable;
 1;
 
 
-
 =pod
 
 =head1 NAME
@@ -103,13 +97,7 @@ Games::Pandemic::Disease - pandemic disease object
 
 =head1 VERSION
 
-version 1.092660
-
-=begin Pod::Coverage
-
-DEMOLISH
-
-=end Pod::Coverage
+version 1.111010
 
 =head1 METHODS
 
@@ -118,11 +106,11 @@ DEMOLISH
 Return the C<$path> to an image for the disease. C<$what> can be either
 C<cube> or C<cure>.
 
-
+=for Pod::Coverage DEMOLISH
 
 =head1 AUTHOR
 
-  Jerome Quelin
+Jerome Quelin
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -132,8 +120,8 @@ This is free software, licensed under:
 
   The GNU General Public License, Version 2, June 1991
 
-=cut 
+=cut
 
 
+__END__
 
-__END__
\ No newline at end of file
