@@ -1,19 +1,20 @@
-# 
+#
 # This file is part of Games-Pandemic
-# 
+#
 # This software is Copyright (c) 2009 by Jerome Quelin.
-# 
+#
 # This is free software, licensed under:
-# 
+#
 #   The GNU General Public License, Version 2, June 1991
-# 
+#
 use 5.010;
 use strict;
 use warnings;
 
 package Games::Pandemic::Tk::Dialog::GiveCard;
-our $VERSION = '1.092660';
-
+BEGIN {
+  $Games::Pandemic::Tk::Dialog::GiveCard::VERSION = '1.111010';
+}
 # ABSTRACT: pandemic dialog to give cards
 
 use Moose;
@@ -21,11 +22,12 @@ use MooseX::SemiAffordanceAccessor;
 use POE;
 use Readonly;
 use Tk;
+use Tk::Sugar;
 
 extends 'Games::Pandemic::Tk::Dialog';
 
+use Games::Pandemic::Tk::Utils qw{ image };
 use Games::Pandemic::Utils;
-use Games::Pandemic::Tk::Utils;
 
 Readonly my $K => $poe_kernel;
 
@@ -83,7 +85,7 @@ augment _build_gui => sub {
     my $self = shift;
     my $top  = $self->_toplevel;
 
-    my $fcenter = $top->Frame->pack(@TOP, @XFILL2);
+    my $fcenter = $top->Frame->pack(top, xfill2);
 
 
     # if more than one player, select which one will receive the card
@@ -91,28 +93,28 @@ augment _build_gui => sub {
     $self->_set_player( $players[0] );
     if ( @players > 1 ) {
         # enclose players in their own frame
-        my $f = $fcenter->Frame->pack(@LEFT, @PAD10, -anchor=>'nw');
+        my $f = $fcenter->Frame->pack(left, pad10, NW);
         $f->Label(
             -text   => T('Select player receiving the card:'),
             -anchor => 'w',
-        )->pack(@TOP, @FILLX);
+        )->pack(top, fillx);
 
         # display players
         my $selplayer = $self->_player->role;
         foreach my $player ( @players ) {
             # to display a radiobutton with image + text, we need to
             # create a radiobutton with a label just next to it.
-            my $fplayer = $f->Frame->pack(@TOP, @FILLX);
+            my $fplayer = $f->Frame->pack(top, fillx);
             my $rb = $fplayer->Radiobutton(
                 -text     => $player->role,
                 -variable => \$selplayer,
                 -value    => $player->role,
                 -anchor   => 'w',
                 -command  => sub{ $self->_set_player($player); },
-            )->pack(@LEFT, @XFILLX);
+            )->pack(left, xfillx);
             my $lab = $fplayer->Label(
                 -image    => image( $player->image('icon', 32), $top ),
-            )->pack(@LEFT);
+            )->pack(left);
             $lab->bind( '<1>', sub { $rb->invoke; } );
         }
     }
@@ -122,28 +124,28 @@ augment _build_gui => sub {
     $self->_set_card( $cards[0] );
     if ( @cards > 1 ) {
         # enclosed cards in their own frame
-        my $f = $fcenter->Frame->pack(@LEFT, @FILLX, @PAD10, -anchor=>'nw');
+        my $f = $fcenter->Frame->pack(left, fillx, pad10, NW);
         $f->Label(
             -text   => T('Select city card to give:'),
             -anchor => 'w',
-        )->pack(@TOP, @FILLX);
+        )->pack(top, fillx);
 
         # display cards
         my $selcard = $self->_card->label;
         foreach my $card ( @cards ) {
             # to display a radiobutton with image + text, we need to
             # create a radiobutton with a label just next to it.
-            my $fcity = $f->Frame->pack(@TOP, @FILLX);
+            my $fcity = $f->Frame->pack(top, fillx);
             my $rb = $fcity->Radiobutton(
                 -image    => image($card->icon, $top),
                 -variable => \$selcard,
                 -value    => $card->label,
                 -command  => sub { $self->_set_card($card); },
-            )->pack(@LEFT);
+            )->pack(left);
             my $lab = $fcity->Label(
                 -text   => $card->label,
                 -anchor => 'w',
-            )->pack(@LEFT, @FILLX);
+            )->pack(left, fillx);
             $lab->bind( '<1>', sub { $rb->invoke; } );
         }
     }
@@ -157,7 +159,6 @@ __PACKAGE__->meta->make_immutable;
 1;
 
 
-
 =pod
 
 =head1 NAME
@@ -166,13 +167,7 @@ Games::Pandemic::Tk::Dialog::GiveCard - pandemic dialog to give cards
 
 =head1 VERSION
 
-version 1.092660
-
-=begin Pod::Coverage
-
-BUILD
-
-=end Pod::Coverage
+version 1.111010
 
 =head1 SYNOPSIS
 
@@ -192,9 +187,11 @@ C<@players> currently in the city. When clicking ok, the selected card
 will be given to the selected player. This takes one action, and is
 handled by L<Games::Pandemic::Controller>.
 
+=for Pod::Coverage BUILD
+
 =head1 AUTHOR
 
-  Jerome Quelin
+Jerome Quelin
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -204,8 +201,8 @@ This is free software, licensed under:
 
   The GNU General Public License, Version 2, June 1991
 
-=cut 
+=cut
 
 
+__END__
 
-__END__
\ No newline at end of file
