@@ -1,30 +1,32 @@
-# 
+#
 # This file is part of Games-Pandemic
-# 
+#
 # This software is Copyright (c) 2009 by Jerome Quelin.
-# 
+#
 # This is free software, licensed under:
-# 
+#
 #   The GNU General Public License, Version 2, June 1991
-# 
+#
 use 5.010;
 use strict;
 use warnings;
 
 package Games::Pandemic::Tk::Dialog::ViewCards;
-our $VERSION = '1.092660';
-
+BEGIN {
+  $Games::Pandemic::Tk::Dialog::ViewCards::VERSION = '1.111010';
+}
 # ABSTRACT: dialog window to show cards
 
 use Moose;
 use MooseX::SemiAffordanceAccessor;
 use Tk;
+use Tk::Sugar;
 use Tk::Tiler;
 
 extends 'Games::Pandemic::Tk::Dialog';
 
 use Games::Pandemic::Utils;
-use Games::Pandemic::Tk::Utils;
+use Games::Pandemic::Tk::Utils qw{ image };
 
 
 # -- accessors
@@ -61,7 +63,7 @@ augment _build_gui => sub {
         -scrollbars => 'oe',
         -rows       => 8,
         -columns    => 3,
-    )->pack(@TOP, @XFILL2, @PAD2);
+    )->pack(top, xfill2, pad2);
     #$tiler->Manage( $tiler->Label(-text=>T('(older)'), -anchor=>'w') );
 
     # display cards
@@ -69,8 +71,8 @@ augment _build_gui => sub {
         # to display a checkbutton with image + text, we need to
         # create a checkbutton with a label just next to it.
         my $fcard = $tiler->Frame;
-        $fcard->Label( -image => image($card->icon, $top) )->pack(@LEFT);
-        $fcard->Label( -text  => $card->label, -anchor => 'w' )->pack(@LEFT, @FILLX);
+        $fcard->Label( -image => image($card->icon, $top) )->pack(left);
+        $fcard->Label( -text  => $card->label, W )->pack(left, fillx);
         $tiler->Manage($fcard);
     }
     #$tiler->Manage( $tiler->Label(-text=>T('(more recent)')) );
@@ -84,7 +86,6 @@ __PACKAGE__->meta->make_immutable;
 1;
 
 
-
 =pod
 
 =head1 NAME
@@ -93,17 +94,13 @@ Games::Pandemic::Tk::Dialog::ViewCards - dialog window to show cards
 
 =head1 VERSION
 
-version 1.092660
+version 1.111010
 
-=begin Pod::Coverage
-
-BUILD
-
-=end Pod::Coverage
+=for Pod::Coverage BUILD
 
 =head1 AUTHOR
 
-  Jerome Quelin
+Jerome Quelin
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -113,8 +110,8 @@ This is free software, licensed under:
 
   The GNU General Public License, Version 2, June 1991
 
-=cut 
+=cut
 
 
+__END__
 
-__END__
\ No newline at end of file
